__version__ = '0.0.13'
__usage__ = """
    USAGE:
        As a module from any location
            python3 -m myhttps [-option value]

    OPTIONS:
        --v             Version Info(**)
        --help          Help and usage Info(**)
        -p              Port Number [default: 11443]
        -h              Host address
        -c              ssl cert file location
        -k              ssl key file location
        -mode           HTTPS or HTTP

"""
